Docstripy - Convert any docstring to any format docstring
=========================================================

Transform your python docstrings to the format you want :sparkles:

Support Nympydoc, Google and ReStructuredText as output styles. The
input style should be either Numpy, Google, ReST or even a mix of both.

Python notebook are supported as well!

|Release| |PythonVersion| |License|

|Ruff_logo| |Black_logo|

|Ruff| |Flake8| |MyPy| |PyLint|

|Tests| |Coverage|

.. |Release| image:: https://img.shields.io/github/v/tag/valentingol/docstripy?label=Pypi&logo=pypi&logoColor=yellow
   :target: https://pypi.org/project/docstripy/
.. |PythonVersion| image:: https://img.shields.io/badge/Python-3.7%20%7E%203.11-informational
.. |License| image:: https://img.shields.io/github/license/valentingol/docstripy?color=999
   :target: https://stringfixer.com/fr/MIT_license
.. |Ruff_logo| image:: https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v1.json
   :target: https://github.com/charliermarsh/ruff
.. |Black_logo| image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
.. |Ruff| image:: https://github.com/valentingol/docstripy/actions/workflows/ruff.yaml/badge.svg
   :target: https://github.com/valentingol/docstripy/actions/workflows/ruff.yaml
.. |Flake8| image:: https://github.com/valentingol/docstripy/actions/workflows/flake.yaml/badge.svg
   :target: https://github.com/valentingol/docstripy/actions/workflows/flake.yaml
.. |MyPy| image:: https://github.com/valentingol/docstripy/actions/workflows/mypy.yaml/badge.svg
   :target: https://github.com/valentingol/docstripy/actions/workflows/mypy.yaml
.. |PyLint| image:: https://img.shields.io/endpoint?url=https://gist.githubusercontent.com/valentingol/5816178f37cee2c013f2e656666c898a/raw/npdocify_pylint.json
   :target: https://github.com/valentingol/docstripy/actions/workflows/pylint.yaml
.. |Tests| image:: https://github.com/valentingol/docstripy/actions/workflows/tests.yaml/badge.svg
   :target: https://github.com/valentingol/docstripy/actions/workflows/tests.yaml
.. |Coverage| image:: https://img.shields.io/endpoint?url=https://gist.githubusercontent.com/valentingol/6fd638b90ac10eced712b8d5ca83b04f/raw/npdocify_tests.json
   :target: https://github.com/valentingol/docstripy/actions/workflows/tests.yaml

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   howto
   features
   docstripy_api
   contribute
   license
